@@ -6,7 +6,7 @@ from typing import Literal, List, Optional
 from xml.etree.ElementTree import Element
 
 from Annotations2Sub.Color import Alpha, Color
-from Annotations2Sub.locales import _
+from Annotations2Sub.locale import _
 
 
 class Annotation(object):
@@ -43,34 +43,30 @@ class Annotation(object):
 def Parse(tree: Element) -> List[Annotation]:
     """XML 树转换为 Annotation 结构列表"""
 
-    def ParseAnnotationAlpha(annotation_alpha_str: str) -> Alpha:
+    def ParseAnnotationAlpha(s: str) -> Alpha:
         """
         解析 Annotation 的透明度
         bgAlpha="0.600000023842" -> Alpha(alpha=102)
         """
-        s0 = annotation_alpha_str
-        if s0 == None:
+        if s is None:
             raise Exception("alpha is None")
-        s1 = float(s0)
+        s1 = float(s)
         s2 = 1 - s1
         s3 = s2 * 255
         s4 = int(s3)
-        s5 = Alpha(alpha=s4)
-        return s5
+        return Alpha(alpha=s4)
 
-    def ParseAnnotationColor(annotation_color_str: str) -> Color:
+    def ParseAnnotationColor(s: str) -> Color:
         """
         bgColor="4210330" -> Color(red=154, green=62, blue=64)
         """
-        s0 = annotation_color_str
-        if s0 == None:
+        if s is None:
             raise Exception("color is None")
-        s1 = int(s0)
+        s1 = int(s)
         r = s1 & 255
         g = (s1 >> 8) & 255
         b = s1 >> 16
-        s2 = Color(red=r, green=g, blue=b)
-        return s2
+        return Color(red=r, green=g, blue=b)
 
     def MakeSureStr(s: Optional[str]) -> str:
         if isinstance(s, str):
@@ -86,11 +82,14 @@ def Parse(tree: Element) -> List[Annotation]:
 
         type = each.get("type")
         if type not in ("text", "highlight", "branding"):
-            print(_("本脚本暂不支持{}类型. ()").format(type, annotation.id))
+            print(_("不支持{}类型. ()").format(type, annotation.id))
             return None
         annotation.type = MakeSureStr(type)  # type: ignore
 
-        annotation.style = each.get("style")  # type: ignore
+        style = each.get("style")
+        if style is None:
+            return None
+        annotation.style = style  # type: ignore
 
         text = each.find("TEXT")
         if text is None:
@@ -139,13 +138,13 @@ def Parse(tree: Element) -> List[Annotation]:
         sx = Segment[0].get("sx")
         sy = Segment[0].get("sy")
 
-        if w is not None:
+        if w != None:
             annotation.width = float(MakeSureStr(w))
-        if h is not None:
+        if h != None:
             annotation.height = float(MakeSureStr(h))
-        if sx is not None:
+        if sx != None:
             annotation.sx = float(MakeSureStr(sx))
-        if sy is not None:
+        if sy != None:
             annotation.sy = float(MakeSureStr(sy))
 
         Appearance = each.find("appearance")
@@ -156,14 +155,14 @@ def Parse(tree: Element) -> List[Annotation]:
             fgColor = Appearance.get("fgColor")  # type: ignore
             textSize = Appearance.get("textSize")  # type: ignore
 
-        if bgAlpha != None:
-            annotation.bgOpacity = ParseAnnotationAlpha(MakeSureStr(bgAlpha))
-        if bgColor != None:
-            annotation.bgColor = ParseAnnotationColor(MakeSureStr(bgColor))
-        if fgColor != None:
-            annotation.fgColor = ParseAnnotationColor(MakeSureStr(fgColor))
-        if textSize != None:
-            annotation.textSize = float(MakeSureStr(textSize))
+            if bgAlpha != None:
+                annotation.bgOpacity = ParseAnnotationAlpha(MakeSureStr(bgAlpha))
+            if bgColor != None:
+                annotation.bgColor = ParseAnnotationColor(MakeSureStr(bgColor))
+            if fgColor != None:
+                annotation.fgColor = ParseAnnotationColor(MakeSureStr(fgColor))
+            if textSize != None:
+                annotation.textSize = float(MakeSureStr(textSize))
 
         return annotation
 
